/**
 * Ampli - A strong typed wrapper for your Analytics
 *
 * This file is generated by Amplitude.
 * To update run 'ampli pull integration-functions'
 *
 * Required dependencies: @amplitude/analytics-node@^0.5.0
 * Tracking Plan Version: 158
 * Build: 1.0.0
 * Runtime: node.js:typescript-ampli-v2
 *
 * [View Tracking Plan](https://data.amplitude.com/netlify-1232/Netlify/events/main/latest)
 *
 * [Full Setup Instructions](https://data.amplitude.com/netlify-1232/Netlify/implementation/integration-functions)
 */
import * as amplitude from '@amplitude/analytics-node';
export type NodeClient = amplitude.Types.NodeClient;
export type BaseEvent = amplitude.Types.BaseEvent;
export type Event = amplitude.Types.Event;
export type EventOptions = amplitude.Types.EventOptions;
export type Result = amplitude.Types.Result;
export type NodeOptions = amplitude.Types.NodeOptions;
export type Environment = 'production' | 'development';
export declare const ApiKey: Record<Environment, string>;
/**
* Default Amplitude configuration options. Contains tracking plan information.
*/
export declare const DefaultConfiguration: NodeOptions;
export interface LoadOptionsBase {
    disabled?: boolean;
}
export type LoadOptionsWithEnvironment = LoadOptionsBase & {
    environment: Environment;
    client?: {
        configuration?: NodeOptions;
    };
};
export type LoadOptionsWithApiKey = LoadOptionsBase & {
    client: {
        apiKey: string;
        configuration?: NodeOptions;
    };
};
export type LoadOptionsWithClientInstance = LoadOptionsBase & {
    client: {
        instance: NodeClient;
    };
};
export type LoadOptions = LoadOptionsWithEnvironment | LoadOptionsWithApiKey | LoadOptionsWithClientInstance;
export interface IntegrationEmailSendProperties {
    /**
     * provider used for signup; will either be a git provider or "email" for email and password
     */
    provider: string;
}
export interface IntegrationSentryCronMonitoringEnabledProperties {
    functionName: string;
}
export interface IntegrationSentryEnabledProperties {
    functionName: string;
}
export declare class IntegrationEmailSend implements BaseEvent {
    event_properties: IntegrationEmailSendProperties;
    event_type: string;
    constructor(event_properties: IntegrationEmailSendProperties);
}
export declare class IntegrationSentryCronMonitoringEnabled implements BaseEvent {
    event_properties: IntegrationSentryCronMonitoringEnabledProperties;
    event_type: string;
    constructor(event_properties: IntegrationSentryCronMonitoringEnabledProperties);
}
export declare class IntegrationSentryEnabled implements BaseEvent {
    event_properties: IntegrationSentryEnabledProperties;
    event_type: string;
    constructor(event_properties: IntegrationSentryEnabledProperties);
}
export type PromiseResult<T> = {
    promise: Promise<T | void>;
};
export declare class Ampli {
    private disabled;
    private amplitude?;
    get client(): NodeClient;
    get isLoaded(): boolean;
    private isInitializedAndEnabled;
    /**
     * Initialize the Ampli SDK. Call once when your application starts.
     *
     * @param options Configuration options to initialize the Ampli SDK with.
     */
    load(options: LoadOptions): PromiseResult<void>;
    /**
     * Identify a user and set user properties.
     *
     * @param userId The user's id.
     * @param options Optional event options.
     */
    identify(userId: string | undefined, options?: EventOptions): PromiseResult<Result>;
    /**
     * Set Group for the user.
     *
     * @param userId The user's id.
     * @param groupType The group type.
     * @param groupName The group name.
     * @param options Optional event options.
     */
    setGroup(userId: string | undefined, groupType: string, groupName: string | string[], options?: EventOptions): PromiseResult<Result>;
    /**
     * Identify a group and set group properties.
     *
     * @param groupType The group type.
     * @param groupName The group name.
     * @param options Optional event options.
     */
    groupIdentify(groupType: string, groupName: string | string[], options?: EventOptions): PromiseResult<Result>;
    /**
     * Track event
     *
     * @param userId The user's id.
     * @param event The event to track.
     * @param options Optional event options.
     */
    track(userId: string | undefined, event: Event, options?: EventOptions): PromiseResult<Result>;
    flush(): PromiseResult<void>;
    /**
     * integration:email-send
     *
     * [View in Tracking Plan](https://data.amplitude.com/netlify-1232/Netlify/events/main/latest/integration%3Aemail-send)
     *
     * Owner: Ed Stephinson
     *
     * @param userId The user's ID.
     * @param properties The event's properties (e.g. provider)
     * @param options Amplitude event options.
     */
    integrationEmailSend(userId: string | undefined, properties: IntegrationEmailSendProperties, options?: EventOptions): PromiseResult<amplitude.Types.Result>;
    /**
     * integration:sentry_cron_monitoring_enabled
     *
     * [View in Tracking Plan](https://data.amplitude.com/netlify-1232/Netlify/events/main/latest/integration%3Asentry_cron_monitoring_enabled)
     *
     * Tracks whether Sentry's Cron Monitoring feature is enabled for a Netlify Function. This should realistically only be used by Netlify Scheduled Functions
     *
     * Owner: erica.pisani@netlify.com
     *
     * @param userId The user's ID.
     * @param properties The event's properties (e.g. functionName)
     * @param options Amplitude event options.
     */
    integrationSentryCronMonitoringEnabled(userId: string | undefined, properties: IntegrationSentryCronMonitoringEnabledProperties, options?: EventOptions): PromiseResult<amplitude.Types.Result>;
    /**
     * integration:sentry_enabled
     *
     * [View in Tracking Plan](https://data.amplitude.com/netlify-1232/Netlify/events/main/latest/integration%3Asentry_enabled)
     *
     * Tracks if Sentry is enabled for a given Netlify Function (Standard, Background, and Scheduled)
     *
     * Owner: erica.pisani@netlify.com
     *
     * @param userId The user's ID.
     * @param properties The event's properties (e.g. functionName)
     * @param options Amplitude event options.
     */
    integrationSentryEnabled(userId: string | undefined, properties: IntegrationSentryEnabledProperties, options?: EventOptions): PromiseResult<amplitude.Types.Result>;
}
export declare const ampli: Ampli;
